@@ -1,2 +1,2 @@
 from .backgrounds import * 
-from .xmcd import *
\ No newline at end of file
+from .polarized import *
\ No newline at end of file
